//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

  WSGIappLocaleSet()->setLocaleString("en_US","","");
  WSGIappLocaleSet()->setLocaleString("en_US","B4:WSSTR Confirmation","Confirmation");
  WSGIappLocaleSet()->setLocaleString("en_US","C4:WSSTR ObjectBox","ObjectBox");
  WSGIappLocaleSet()->setLocaleString("en_US","D4:WSSTR ProjectSettings","ProjectSettings");
  WSGIappLocaleSet()->setLocaleString("en_US","E4:WSSTR New project","New project");
  WSGIappLocaleSet()->setLocaleString("en_US","F4:WSSTR Open project","Open project");
  WSGIappLocaleSet()->setLocaleString("en_US","G4:WSSTR Save project","Save project");
  WSGIappLocaleSet()->setLocaleString("en_US","H4:WSSTR Close project","Close project");
  WSGIappLocaleSet()->setLocaleString("en_US","I4:WSSTR New application window","New application window");
  WSGIappLocaleSet()->setLocaleString("en_US","J4:WSSTR Open application window","Open application window");
  WSGIappLocaleSet()->setLocaleString("en_US","K4:WSSTR Save application window","Save application window");
  WSGIappLocaleSet()->setLocaleString("en_US","L4:WSSTR Delete instance","Delete instance");
  WSGIappLocaleSet()->setLocaleString("en_US","M4:WSSTR Properties","Properties");
  WSGIappLocaleSet()->setLocaleString("en_US","N4:WSSTR Procedures","Procedures");
  WSGIappLocaleSet()->setLocaleString("en_US","O4:WSSTR Display the object box","Display the object box");
  WSGIappLocaleSet()->setLocaleString("en_US","P4:WSSTR Project settings","Project settings");
  WSGIappLocaleSet()->setLocaleString("en_US","Q4:WSSTR Build all","Build all");
  WSGIappLocaleSet()->setLocaleString("en_US","Q4:WSSTR Cancel","Cancel");
  WSGIappLocaleSet()->setLocaleString("en_US","R4:WSSTR Execute","Execute");
  WSGIappLocaleSet()->setLocaleString("en_US","S4:WSSTR Find instances","Find instances");
  WSGIappLocaleSet()->setLocaleString("en_US","T4:WSSTR Find files","Find files");
  WSGIappLocaleSet()->setLocaleString("en_US","U4:WSSTR Help","Help");
  WSGIappLocaleSet()->setLocaleString("en_US","V4:WSSTR  File(F)"," File(F)");
  WSGIappLocaleSet()->setLocaleString("en_US","W4:WSSTR New window(N)         :m11:N,Open window(O):m12:O,Save window(S):m13:S,Save as(R):m14:R,Save all(A):m15:A,SP,Exit(X):m16:X","New window(N)         :m11:N:0:$(WSDIR)/sys/pixmaps/wcreate.png,Open window(O):m12:O:0:$(WSDIR)/sys/pixmaps/wload.png,Save window(S):m13:S:0:$(WSDIR)/sys/pixmaps/wsave.png,Save as(R):m14:R,Save all(A):m15:A,SP,Exit(X):m16:X:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("en_US","X4:WSSTR  Edit(E)"," Edit(E)");
  WSGIappLocaleSet()->setLocaleString("en_US","Y4:WSSTR Copy(C):m21:C,Paste(P):m22:P,SP,Display(I):m27:I,Find(F):m28:F,Delete(D):m23:D,SP,Properties(R):m24:R,Procedures:{List up(L):m25:L,New procedure(N):m251:N,Properties(S):m252:S,Edit(E):m253:E,Delete(X):m254:X},Attributes(A):m26:A,Files(L):m29:L","Undo(U):m291:U:1,Copy(C):m21:C,Paste(P):m22:P,SP,Display(I):m27:I,Find(F):m28:F,Delete(D):m23:D,SP,Properties(R):m24:R,Procedures:{List up(L):m25:L,New procedure(N):m251:N,Properties(S):m252:S,Edit(E):m253:E,Delete(X):m254:X},Attributes(A):m26:A,Files(L):m29:L");
  WSGIappLocaleSet()->setLocaleString("en_US","Z4:WSSTR  Build(B)"," Build(B)");
  WSGIappLocaleSet()->setLocaleString("en_US","a4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Execute(X):m36:X,Execute with Trace(T):m39:T,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","Compile(C)    :m31:C,Build all(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Execute(X):m36:X:0:$(WSDIR)/sys/pixmaps/run.png,Execute with Trace(T):m39:T,SP,Generate source(G):m37:G,Generate inf file(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("en_US","b4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Abort(X):m36:X,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","Compile(C)    :m31:C,Build all(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Abort(X):m36:X:0:$(WSDIR)/sys/pixmaps/runx.png,SP,Generate source(G):m37:G,Generate inf file(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("en_US","c4:WSSTR  View(V)"," View(V)");
  WSGIappLocaleSet()->setLocaleString("en_US","d4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Terminal(T):m45:T","Folders(D) :m46:D,Inspector(I) :m47:I,InstanceEditor(E) :m48:E,ClassList(L) :m49:L,ObjectBox(O) :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,Component(C)    :m42:C,ToolBar(B):m43:B,SP,Terminal(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("en_US","e4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Find Files(F):m44:F,Terminal(T):m45:T","Folders(D) :m46:D,Inspector(I) :m47:I,InstanceEditor(E) :m48:E,ClassList(L) :m49:L,ObjectBox(O) :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,Component(C)    :m42:C,ToolBar(B):m43:B,SP,Find Files(F):m44:F,Terminal(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("en_US","f4:WSSTR  Project(P)"," Project(P)");
  WSGIappLocaleSet()->setLocaleString("en_US","g4:WSSTR New project(N)        :m51:N,Open project(O):m52:O,Save project(S):m53:S,Rename project(R):m54:R,SP,Project settings(E):m55:E,SP,Close project(C):m56:C","New project(N)        :m51:N:0:$(WSDIR)/sys/pixmaps/pcreate.png,Open project(O):m52:O:0:$(WSDIR)/sys/pixmaps/pload.png,Save project(S):m53:S:0:$(WSDIR)/sys/pixmaps/psave.png,Rename project(R):m54:R,SP,Project settings(E):m55:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,Close project(C):m56:C:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("en_US","h4:WSSTR  Option(O)"," Option(O)");
  WSGIappLocaleSet()->setLocaleString("en_US","i4:WSSTR Environment(E)    :m61:E,SP,Colors(C):m62:C,Fonts(F):m63:F,Look and Feel(L):m64:L","Environment(E)    :m61:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,Colors(C):m62:C,Fonts(F):m63:F,Look and Feel(L):m64:L");
  WSGIappLocaleSet()->setLocaleString("en_US","j4:WSSTR  Help(H)"," Help(H)");
  WSGIappLocaleSet()->setLocaleString("en_US","k4:WSSTR Index(I):m81:I,Reference(R)     :m82:R,User's guide(U):m83:U,About WideStudio(V):m84:V,License(L):m85:L","Index(I):m81:I:0:$(WSDIR)/sys/pixmaps/help.png,Reference(R)     :m82:R,User's guide(U):m83:U,About WideStudio(V):m84:V,License(L):m85:L");
  WSGIappLocaleSet()->setLocaleString("en_US","l4:WSSTR Please specify a window to save.","Please specify a window to save.");
  WSGIappLocaleSet()->setLocaleString("en_US","m4:WSSTR Continue saving?","Continue saving?");
  WSGIappLocaleSet()->setLocaleString("en_US","n4:WSSTR Please specify some instances to copy.","Please specify some instances to copy.");
  WSGIappLocaleSet()->setLocaleString("en_US","o4:WSSTR Please specify a instance to paste.","Please specify a instance to paste.");
  WSGIappLocaleSet()->setLocaleString("en_US","p4:WSSTR Some instances are selected to paste.\nPlease specify a instance.","Some instances are selected to paste.\nPlease specify a instance.");
  WSGIappLocaleSet()->setLocaleString("en_US","q4:WSSTR Please select the instance to delete.","Please select the instance to delete.");
  WSGIappLocaleSet()->setLocaleString("en_US","r4:WSSTR Delete instance: ","Delete instance: ");
  WSGIappLocaleSet()->setLocaleString("en_US","s4:WSSTR  ?"," ?");
  WSGIappLocaleSet()->setLocaleString("en_US","t4:WSSTR Please specify a instance to display.","Please specify a instance to display.");
  WSGIappLocaleSet()->setLocaleString("en_US","u4:WSSTR There is no instance for search.","There is no instance for search.");
  WSGIappLocaleSet()->setLocaleString("en_US","v4:WSSTR Please specify a application window to compile.","Please specify a application window to compile.");
  WSGIappLocaleSet()->setLocaleString("en_US","w4:WSSTR Please check the debugger settings or confirm whether the project is built.","Please check the debugger settings or confirm whether the project is built.");
  WSGIappLocaleSet()->setLocaleString("en_US","x4:WSSTR Can not execute the class library...","Can not execute the class library...");
  WSGIappLocaleSet()->setLocaleString("en_US","y4:WSSTR Can not execute the load module.\nPlease confirm whether the project is collect or built.","Can not execute the load module.\nPlease confirm whether the project is collect or built.");
  WSGIappLocaleSet()->setLocaleString("en_US","z4:WSSTR Please specify a application window to generate source code.","Please specify a application window to generate source code.");
  WSGIappLocaleSet()->setLocaleString("en_US","A4:WSSTR Please wait for a while to start web browser..","Please wait for a while to start web browser..");
  WSGIappLocaleSet()->setLocaleString("en_US","B4:WSSTR NoName","NoName");
  WSGIappLocaleSet()->setLocaleString("en_US","C4:WSSTR Unexpected error occurred in reading the project files...","Unexpected error occurred in reading the project files...");
  WSGIappLocaleSet()->setLocaleString("en_US","D4:WSSTR Can not open File: ","Can not open File: ");
  WSGIappLocaleSet()->setLocaleString("en_US","E4:WSSTR  ."," .");
  WSGIappLocaleSet()->setLocaleString("en_US","F4:WSSTR Can not save FILE: ","Can not save FILE: ");
  WSGIappLocaleSet()->setLocaleString("en_US","G4:WSSTR  ."," .");
  WSGIappLocaleSet()->setLocaleString("en_US","H4:WSSTR The project was modified.\nSave it?","The project was modified.\nSave it?");
  WSGIappLocaleSet()->setLocaleString("en_US","I4:WSSTR Abort saving the application window.","Abort saving the application window.");
  WSGIappLocaleSet()->setLocaleString("en_US","J4:WSSTR Some application windows were modified \nSave them?","Some application windows were modified \nSave them?");
  WSGIappLocaleSet()->setLocaleString("en_US","K4:WSSTR The project has no name.\nName the project and save it?","The project has no name.\nName the project and save it?");
  WSGIappLocaleSet()->setLocaleString("en_US","L4:WSSTR Exit the application builder?","Exit the application builder?");
  WSGIappLocaleSet()->setLocaleString("en_US","M4:WSSTR Sorry, under construction...","Sorry, under construction...");
  WSGIappLocaleSet()->setLocaleString("en_US","N4:WSSTR Failed to save FILE: ","Failed to save FILE: ");
  WSGIappLocaleSet()->setLocaleString("en_US","O4:WSSTR Do you continue?","Do you continue?");
  WSGIappLocaleSet()->setLocaleString("en_US","P4:WSSTR \",\n","\",\n");
  WSGIappLocaleSet()->setLocaleString("en_US","Q4:WSSTR No project is specified.\nGenerate a new project?","No project is specified.\nGenerate a new project?");
  WSGIappLocaleSet()->setLocaleString("en_US","R4:WSSTR Please specify a keyword to search files.","Please specify a keyword to search files.");
  WSGIappLocaleSet()->setLocaleString("en_US","S4:WSSTR No editor is specified.\nPlease confirm the project settings and specify the editor.","No editor is specified.\nPlease confirm the project settings and specify the editor.");
  WSGIappLocaleSet()->setLocaleString("en_US","S4:WSSTR No editor option is specified.\nPlease confirm the project settings and specify the editor.","No editor option is specified.\nPlease confirm the project settings and specify the editor.");
  WSGIappLocaleSet()->setLocaleString("en_US","T4:WSSTR New project","New project");
  WSGIappLocaleSet()->setLocaleString("en_US","U4:WSSTR < Back,Next >,Finish","< Back,Next >,Finish");
  WSGIappLocaleSet()->setLocaleString("en_US","V4:WSSTR Project name","Project name");
  WSGIappLocaleSet()->setLocaleString("en_US","W4:WSSTR Working dir","Working dir");
  WSGIappLocaleSet()->setLocaleString("en_US","X4:WSSTR Project type","Project type");
  WSGIappLocaleSet()->setLocaleString("en_US","Y4:WSSTR  Normal application"," Normal application");
  WSGIappLocaleSet()->setLocaleString("en_US","Z4:WSSTR  Class library component"," Class library component");
  WSGIappLocaleSet()->setLocaleString("en_US","W4:WSSTR New application window","New application window");
  WSGIappLocaleSet()->setLocaleString("en_US","X4:WSSTR < Back,Next >,Finish","< Back,Next >,Finish");
  WSGIappLocaleSet()->setLocaleString("en_US","Y4:WSSTR Type","Type");
  WSGIappLocaleSet()->setLocaleString("en_US","Z4:WSSTR  Normal window"," Normal window");
  WSGIappLocaleSet()->setLocaleString("en_US","a4:WSSTR  Class"," Class");
  WSGIappLocaleSet()->setLocaleString("en_US","b4:WSSTR Project","Project");
  WSGIappLocaleSet()->setLocaleString("en_US","c4:WSSTR  Add to project"," Add to project");
  WSGIappLocaleSet()->setLocaleString("en_US","d4:WSSTR Name","Name");
  WSGIappLocaleSet()->setLocaleString("en_US","e4:WSSTR Please specify a instance name to search.","Please specify a instance name to search.");
  WSGIappLocaleSet()->setLocaleString("en_US","f4:WSSTR Please specify a value of the property to search instance.","Please specify a value of the property to search instance.");
  WSGIappLocaleSet()->setLocaleString("en_US","f4:WSSTR Please specify a property name likes [WSN...] to search instance.","Please specify a property name likes [WSN...] to search instance.");
  WSGIappLocaleSet()->setLocaleString("en_US","g4:WSSTR Please specify search condition.","Please specify search condition.");
  WSGIappLocaleSet()->setLocaleString("en_US","h4:WSSTR No instance.","No instance.");
  WSGIappLocaleSet()->setLocaleString("en_US","i4:WSSTR Find instances","Find instances");
  WSGIappLocaleSet()->setLocaleString("en_US","j4:WSSTR Find","Find");
  WSGIappLocaleSet()->setLocaleString("en_US","k4:WSSTR Instance name,Properties,Procedures","Instance name,Properties,Procedures");
  WSGIappLocaleSet()->setLocaleString("en_US","l4:WSSTR InstanceName","InstanceName");
  WSGIappLocaleSet()->setLocaleString("en_US","m4:WSSTR Comparison","Comparison");
  WSGIappLocaleSet()->setLocaleString("en_US","n4:WSSTR  Complete equal"," Complete equal");
  WSGIappLocaleSet()->setLocaleString("en_US","o4:WSSTR PropertyName","PropertyName");
  WSGIappLocaleSet()->setLocaleString("en_US","p4:WSSTR Value","Value");
  WSGIappLocaleSet()->setLocaleString("en_US","q4:WSSTR ProcedureName","ProcedureName");
  WSGIappLocaleSet()->setLocaleString("en_US","r4:WSSTR FunctionName","FunctionName");
  WSGIappLocaleSet()->setLocaleString("en_US","s4:WSSTR Direction","Direction");
  WSGIappLocaleSet()->setLocaleString("en_US","t4:WSSTR  Downward"," Downward");
  WSGIappLocaleSet()->setLocaleString("en_US","u4:WSSTR  Upward"," Upward");
  WSGIappLocaleSet()->setLocaleString("en_US","v4:WSSTR Find files","Find files");
  WSGIappLocaleSet()->setLocaleString("en_US","w4:WSSTR < Back,Find, Find","< Back,Find, Find");
  WSGIappLocaleSet()->setLocaleString("en_US","x4:WSSTR Dir:","Dir:");
  WSGIappLocaleSet()->setLocaleString("en_US","y4:WSSTR File type:","File type:");
  WSGIappLocaleSet()->setLocaleString("en_US","z4:WSSTR Keyword:","Keyword:");
  WSGIappLocaleSet()->setLocaleString("en_US","A4:WSSTR Failed to save FILE: ","Failed to save FILE: ");
  WSGIappLocaleSet()->setLocaleString("en_US","B4:WSSTR .",".");
  WSGIappLocaleSet()->setLocaleString("en_US","C4:WSSTR Delete instance:","Delete instance:");
  WSGIappLocaleSet()->setLocaleString("en_US","D4:WSSTR ?","?");
  WSGIappLocaleSet()->setLocaleString("en_US","E4:WSSTR Add application window: ","Add application window: ");
  WSGIappLocaleSet()->setLocaleString("en_US","F4:WSSTR  to the project?"," to the project?");
  WSGIappLocaleSet()->setLocaleString("en_US","G4:WSSTR Remove application window: ","Remove application window: ");
  WSGIappLocaleSet()->setLocaleString("en_US","H4:WSSTR  from the project?"," from the project?");
  WSGIappLocaleSet()->setLocaleString("en_US","I4:WSSTR Failed to read file:","Failed to read file:");
  WSGIappLocaleSet()->setLocaleString("en_US","J4:WSSTR .\nDo you stop reading?",".\nDo you stop reading?");
  WSGIappLocaleSet()->setLocaleString("en_US","K4:WSSTR Failed to open File: ","Failed to open File: ");
  WSGIappLocaleSet()->setLocaleString("en_US","L4:WSSTR .",".");
  WSGIappLocaleSet()->setLocaleString("en_US","M4:WSSTR Failed to write File: ","Failed to write File: ");
  WSGIappLocaleSet()->setLocaleString("en_US","N4:WSSTR .",".");
  WSGIappLocaleSet()->setLocaleString("en_US","O4:WSSTR Invalid name: ","Invalid name: ");
  WSGIappLocaleSet()->setLocaleString("en_US","P4:WSSTR .\nPlease specify a usable name in C/C++ variables.",".\nPlease specify a usable name in C/C++ variables.");
  WSGIappLocaleSet()->setLocaleString("en_US","P4:WSSTR .\nAlready used by project name.",".\nAlready used by project name.");
  WSGIappLocaleSet()->setLocaleString("en_US","P4:WSSTR .\nCan not use array name.",".\nCan not use array name.");
  WSGIappLocaleSet()->setLocaleString("en_US","Q4:WSSTR Can not generate the specified class: ","Can not generate the specified class: ");
  WSGIappLocaleSet()->setLocaleString("en_US","R4:WSSTR .",".");
  WSGIappLocaleSet()->setLocaleString("en_US","S4:WSSTR Can not change the specified class: ","Can not change the specified class: ");
  WSGIappLocaleSet()->setLocaleString("en_US","T4:WSSTR  to window type.\nPlease specify a class of window/dialog base."," to window type.\nPlease specify a class of window/dialog base.");
  WSGIappLocaleSet()->setLocaleString("en_US","U4:WSSTR Can not paste the instance on the specified instance: ","Can not paste the instance on the specified instance: ");
  WSGIappLocaleSet()->setLocaleString("en_US","V4:WSSTR .",".");
  WSGIappLocaleSet()->setLocaleString("en_US","W4:WSSTR Can not paste the specified instance: ","Can not paste the specified instance: ");
  WSGIappLocaleSet()->setLocaleString("en_US","X4:WSSTR ,\nbecause it overlap the source and the destination...",",\nbecause it overlap the source and the destination...");
  WSGIappLocaleSet()->setLocaleString("en_US","Y4:WSSTR Locale type","Locale type");
  WSGIappLocaleSet()->setLocaleString("en_US","Y4:WSSTR Language","Language");
  WSGIappLocaleSet()->setLocaleString("en_US","Y4:WSSTR Templates","Templates");
  WSGIappLocaleSet()->setLocaleString("en_US","Z4:WSSTR Can not read file:","Can not read file:");
  WSGIappLocaleSet()->setLocaleString("en_US","a4:WSSTR .",".");
  WSGIappLocaleSet()->setLocaleString("en_US","a4:WSSTR Look and Feel","Look and Feel");
